import * as cookie from 'cookie';
import * as express from 'express';
import * as next from 'next';
/**
 * Parses cookies.
 *
 * @param ctx NextJS page or API context, express context, null or undefined.
 * @param options Options that we pass down to `cookie` library.
 */
export declare function parseCookies(ctx?: Pick<next.NextPageContext, 'req'> | {
    req: next.NextApiRequest;
} | {
    req: express.Request;
} | null | undefined, options?: cookie.CookieParseOptions): {
    [key: string]: string;
};
/**
 * Sets a cookie.
 *
 * @param ctx NextJS page or API context, express context, null or undefined.
 * @param name The name of your cookie.
 * @param value The value of your cookie.
 * @param options Options that we pass down to `cookie` library.
 */
export declare function setCookie(ctx: Pick<next.NextPageContext, 'res'> | {
    res: next.NextApiResponse;
} | {
    res: express.Response;
} | null | undefined, name: string, value: string, options?: cookie.CookieSerializeOptions): {};
/**
 * Destroys a cookie with a particular name.
 *
 * @param ctx NextJS page or API context, express context, null or undefined.
 * @param name Cookie name.
 * @param options Options that we pass down to `cookie` library.
 */
export declare function destroyCookie(ctx: Pick<next.NextPageContext, 'res'> | {
    res: next.NextApiResponse;
} | {
    res: express.Response;
} | null | undefined, name: string, options?: cookie.CookieSerializeOptions): {};
declare const _default: {
    set: typeof setCookie;
    get: typeof parseCookies;
    destroy: typeof destroyCookie;
};
export default _default;
